==> openshift-model-hive-5.12.3-sources.jar: io/fabric8/openshift/api/model/hive/v1/ProvisioningBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ProvisioningBuilder extends io.fabric8.openshift.api.model.hive.v1.ProvisioningFluentImpl<io.fabric8.openshift.api.model.hive.v1.ProvisioningBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.Provisioning,io.fabric8.openshift.api.model.hive.v1.ProvisioningBuilder>{
  public ProvisioningBuilder() {
    this(false);
  }
  public ProvisioningBuilder(java.lang.Boolean validationEnabled) {
    this(new Provisioning(), validationEnabled);
  }
  public ProvisioningBuilder(io.fabric8.openshift.api.model.hive.v1.ProvisioningFluent<?> fluent) {
    this(fluent, false);
  }
  public ProvisioningBuilder(io.fabric8.openshift.api.model.hive.v1.ProvisioningFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Provisioning(), validationEnabled);
  }
  public ProvisioningBuilder(io.fabric8.openshift.api.model.hive.v1.ProvisioningFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.Provisioning instance) {
    this(fluent, instance, false);
  }
  public ProvisioningBuilder(io.fabric8.openshift.api.model.hive.v1.ProvisioningFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.Provisioning instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withImageSetRef(instance.getImageSetRef()); 
    fluent.withInstallConfigSecretRef(instance.getInstallConfigSecretRef()); 
    fluent.withInstallerEnv(instance.getInstallerEnv()); 
    fluent.withInstallerImageOverride(instance.getInstallerImageOverride()); 
    fluent.withManifestsConfigMapRef(instance.getManifestsConfigMapRef()); 
    fluent.withReleaseImage(instance.getReleaseImage()); 
    fluent.withSshKnownHosts(instance.getSshKnownHosts()); 
    fluent.withSshPrivateKeySecretRef(instance.getSshPrivateKeySecretRef()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ProvisioningBuilder(io.fabric8.openshift.api.model.hive.v1.Provisioning instance) {
    this(instance,false);
  }
  public ProvisioningBuilder(io.fabric8.openshift.api.model.hive.v1.Provisioning instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withImageSetRef(instance.getImageSetRef()); 
    this.withInstallConfigSecretRef(instance.getInstallConfigSecretRef()); 
    this.withInstallerEnv(instance.getInstallerEnv()); 
    this.withInstallerImageOverride(instance.getInstallerImageOverride()); 
    this.withManifestsConfigMapRef(instance.getManifestsConfigMapRef()); 
    this.withReleaseImage(instance.getReleaseImage()); 
    this.withSshKnownHosts(instance.getSshKnownHosts()); 
    this.withSshPrivateKeySecretRef(instance.getSshPrivateKeySecretRef()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.ProvisioningFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.Provisioning build() {
    Provisioning buildable = new Provisioning(fluent.getImageSetRef(),fluent.getInstallConfigSecretRef(),fluent.getInstallerEnv(),fluent.getInstallerImageOverride(),fluent.getManifestsConfigMapRef(),fluent.getReleaseImage(),fluent.getSshKnownHosts(),fluent.getSshPrivateKeySecretRef());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ProvisioningBuilder that = (ProvisioningBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.5.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/ProvisioningBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ProvisioningBuilder extends ProvisioningFluentImpl<ProvisioningBuilder> implements VisitableBuilder<Provisioning,ProvisioningBuilder>{
  public ProvisioningBuilder() {
    this(false);
  }
  public ProvisioningBuilder(Boolean validationEnabled) {
    this(new Provisioning(), validationEnabled);
  }
  public ProvisioningBuilder(ProvisioningFluent<?> fluent) {
    this(fluent, false);
  }
  public ProvisioningBuilder(ProvisioningFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Provisioning(), validationEnabled);
  }
  public ProvisioningBuilder(ProvisioningFluent<?> fluent,Provisioning instance) {
    this(fluent, instance, false);
  }
  public ProvisioningBuilder(ProvisioningFluent<?> fluent,Provisioning instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withImageSetRef(instance.getImageSetRef()); 
    fluent.withInstallConfigSecretRef(instance.getInstallConfigSecretRef()); 
    fluent.withInstallerEnv(instance.getInstallerEnv()); 
    fluent.withInstallerImageOverride(instance.getInstallerImageOverride()); 
    fluent.withManifestsConfigMapRef(instance.getManifestsConfigMapRef()); 
    fluent.withReleaseImage(instance.getReleaseImage()); 
    fluent.withSshKnownHosts(instance.getSshKnownHosts()); 
    fluent.withSshPrivateKeySecretRef(instance.getSshPrivateKeySecretRef()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ProvisioningBuilder(Provisioning instance) {
    this(instance,false);
  }
  public ProvisioningBuilder(Provisioning instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withImageSetRef(instance.getImageSetRef()); 
    this.withInstallConfigSecretRef(instance.getInstallConfigSecretRef()); 
    this.withInstallerEnv(instance.getInstallerEnv()); 
    this.withInstallerImageOverride(instance.getInstallerImageOverride()); 
    this.withManifestsConfigMapRef(instance.getManifestsConfigMapRef()); 
    this.withReleaseImage(instance.getReleaseImage()); 
    this.withSshKnownHosts(instance.getSshKnownHosts()); 
    this.withSshPrivateKeySecretRef(instance.getSshPrivateKeySecretRef()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ProvisioningFluent<?> fluent;
  Boolean validationEnabled;
  public Provisioning build() {
    Provisioning buildable = new Provisioning(fluent.getImageSetRef(),fluent.getInstallConfigSecretRef(),fluent.getInstallerEnv(),fluent.getInstallerImageOverride(),fluent.getManifestsConfigMapRef(),fluent.getReleaseImage(),fluent.getSshKnownHosts(),fluent.getSshPrivateKeySecretRef());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
